@@ -1,9 +1,8 @@
-# -*- coding: utf-8 -*-
 """
 CenturyLink Cloud Module
 ========================
 
-.. versionadded:: Oyxgen
+.. versionadded:: 2018.3
 
 The CLC cloud module allows you to manage CLC Via the CLC SDK.
 
@@ -64,25 +63,18 @@ cloud configuration at
 
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
-
 import importlib
 import logging
 import time
 
-# Import salt libs
 import salt.config as config
 import salt.utils.json
 from salt.exceptions import SaltCloudSystemExit
-from salt.ext import six
-
-# Get logging started
-log = logging.getLogger(__name__)
 
 # Attempt to import clc-sdk lib
 try:
-    # when running this in linode's Ubuntu 16.x version the following line is required to get the clc sdk libraries to load
+    # when running this in linode's Ubuntu 16.x version the following line is required
+    # to get the clc sdk libraries to load
     importlib.import_module("clc")
     import clc
 
@@ -99,6 +91,8 @@ try:
 except Exception:  # pylint: disable=broad-except
     pass
 
+log = logging.getLogger(__name__)
+
 
 __virtualname__ = "clc"
 
@@ -114,10 +108,17 @@ def __virtual__():
     return __virtualname__
 
 
+def _get_active_provider_name():
+    try:
+        return __active_provider_name__.value()
+    except AttributeError:
+        return __active_provider_name__
+
+
 def get_configured_provider():
     return config.is_provider_configured(
         __opts__,
-        __active_provider_name__ or __virtualname__,
+        _get_active_provider_name() or __virtualname__,
         ("token", "token_pass", "user", "password",),
     )
 
@@ -300,7 +301,7 @@ def get_build_status(req_id, nodename):
     get the build status from CLC to make sure we don't return to early
     """
     counter = 0
-    req_id = six.text_type(req_id)
+    req_id = str(req_id)
     while counter < 10:
         queue = clc.v1.Blueprint.GetStatus(request_id=(req_id))
         if queue["PercentComplete"] == 100:
@@ -315,7 +316,7 @@ def get_build_status(req_id, nodename):
             log.info(
                 "Creating Cloud VM %s Time out in %s minutes",
                 nodename,
-                six.text_type(10 - counter),
+                str(10 - counter),
             )
             time.sleep(60)
 
@@ -327,7 +328,7 @@ def create(vm_):
     creds = get_creds()
     clc.v1.SetCredentials(creds["token"], creds["token_pass"])
     cloud_profile = config.is_provider_configured(
-        __opts__, __active_provider_name__ or __virtualname__, ("token",)
+        __opts__, _get_active_provider_name() or __virtualname__, ("token",)
     )
     group = config.get_cloud_config_value(
         "group", vm_, __opts__, search_global=False, default=None,
@@ -379,7 +380,7 @@ def create(vm_):
     __utils__["cloud.fire_event"](
         "event",
         "waiting for ssh",
-        "salt/cloud/{0}/waiting_for_ssh".format(name),
+        "salt/cloud/{}/waiting_for_ssh".format(name),
         sock_dir=__opts__["sock_dir"],
         args={"ip_address": vm_["ssh_host"]},
         transport=__opts__["transport"],
