@@ -1,18 +1,14 @@
-# -*- coding: utf-8 -*-
 """
 Module for working with the Glassfish/Payara 4.x management API
-.. versionadded:: Carbon
+.. versionadded:: 2016.11.0
 :depends: requests
 """
-from __future__ import absolute_import, print_function, unicode_literals
+
+import urllib.parse
 
 import salt.defaults.exitcodes
 import salt.utils.json
 from salt.exceptions import CommandExecutionError
-from salt.ext.six.moves.urllib.parse import (  # pylint: disable=no-name-in-module
-    quote,
-    unquote,
-)
 
 try:
     import requests
@@ -42,7 +38,7 @@ def __virtual__():
     else:
         return (
             False,
-            'The "{0}" module could not be loaded: '
+            'The "{}" module could not be loaded: '
             '"requests" is not installed.'.format(__virtualname__),
         )
 
@@ -73,9 +69,9 @@ def _get_url(ssl, url, port, path):
     Returns the URL of the endpoint
     """
     if ssl:
-        return "https://{0}:{1}/management/domain/{2}".format(url, port, path)
+        return "https://{}:{}/management/domain/{}".format(url, port, path)
     else:
-        return "http://{0}:{1}/management/domain/{2}".format(url, port, path)
+        return "http://{}:{}/management/domain/{}".format(url, port, path)
 
 
 def _get_server(server):
@@ -128,7 +124,7 @@ def _api_get(path, server=None):
         url=_get_url(server["ssl"], server["url"], server["port"], path),
         auth=_get_auth(server["user"], server["password"]),
         headers=_get_headers(),
-        verify=False,
+        verify=True,
     )
     return _api_response(response)
 
@@ -143,7 +139,7 @@ def _api_post(path, data, server=None):
         auth=_get_auth(server["user"], server["password"]),
         headers=_get_headers(),
         data=salt.utils.json.dumps(data),
-        verify=False,
+        verify=True,
     )
     return _api_response(response)
 
@@ -158,7 +154,7 @@ def _api_delete(path, data, server=None):
         auth=_get_auth(server["user"], server["password"]),
         headers=_get_headers(),
         params=data,
-        verify=False,
+        verify=True,
     )
     return _api_response(response)
 
@@ -183,7 +179,7 @@ def _get_element_properties(name, element_type, server=None):
     Get an element's properties
     """
     properties = {}
-    data = _api_get("{0}/{1}/property".format(element_type, name), server)
+    data = _api_get("{}/{}/property".format(element_type, name), server)
 
     # Get properties into a dict
     if any(data["extraProperties"]["properties"]):
@@ -198,8 +194,8 @@ def _get_element(name, element_type, server=None, with_properties=True):
     Get an element with or without properties
     """
     element = {}
-    name = quote(name, safe="")
-    data = _api_get("{0}/{1}".format(element_type, name), server)
+    name = urllib.parse.quote(name, safe="")
+    data = _api_get("{}/{}".format(element_type, name), server)
 
     # Format data, get properties if asked, and return the whole thing
     if any(data["extraProperties"]["entity"]):
@@ -220,14 +216,14 @@ def _create_element(name, element_type, data, server=None):
         data["property"] = ""
         for key, value in data["properties"].items():
             if not data["property"]:
-                data["property"] += "{0}={1}".format(key, value.replace(":", "\\:"))
+                data["property"] += "{}={}".format(key, value.replace(":", "\\:"))
             else:
-                data["property"] += ":{0}={1}".format(key, value.replace(":", "\\:"))
+                data["property"] += ":{}={}".format(key, value.replace(":", "\\:"))
         del data["properties"]
 
     # Send request
     _api_post(element_type, _clean_data(data), server)
-    return unquote(name)
+    return urllib.parse.unquote(name)
 
 
 def _update_element(name, element_type, data, server=None):
@@ -235,19 +231,19 @@ def _update_element(name, element_type, data, server=None):
     Update an element, including its properties
     """
     # Urlencode the name (names may have slashes)
-    name = quote(name, safe="")
+    name = urllib.parse.quote(name, safe="")
 
     # Update properties first
     if "properties" in data:
         properties = []
         for key, value in data["properties"].items():
             properties.append({"name": key, "value": value})
-        _api_post("{0}/{1}/property".format(element_type, name), properties, server)
+        _api_post("{}/{}/property".format(element_type, name), properties, server)
         del data["properties"]
 
         # If the element only contained properties
         if not data:
-            return unquote(name)
+            return urllib.parse.unquote(name)
 
     # Get the current data then merge updated data into it
     update_data = _get_element(name, element_type, server, with_properties=False)
@@ -255,18 +251,20 @@ def _update_element(name, element_type, data, server=None):
         update_data.update(data)
     else:
         __context__["retcode"] = salt.defaults.exitcodes.SALT_BUILD_FAIL
-        raise CommandExecutionError("Cannot update {0}".format(name))
+        raise CommandExecutionError("Cannot update {}".format(name))
 
     # Finally, update the element
-    _api_post("{0}/{1}".format(element_type, name), _clean_data(update_data), server)
-    return unquote(name)
+    _api_post("{}/{}".format(element_type, name), _clean_data(update_data), server)
+    return urllib.parse.unquote(name)
 
 
 def _delete_element(name, element_type, data, server=None):
     """
     Delete an element
     """
-    _api_delete("{0}/{1}".format(element_type, quote(name, safe="")), data, server)
+    _api_delete(
+        "{}/{}".format(element_type, urllib.parse.quote(name, safe="")), data, server
+    )
     return name
 
 
@@ -692,4 +690,4 @@ def delete_system_properties(name, server=None):
     """
     Delete a system property
     """
-    _api_delete("system-properties/{0}".format(name), None, server)
+    _api_delete("system-properties/{}".format(name), None, server)
