@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Module for controlling Jenkins
 
 :depends: python-jenkins
@@ -21,92 +21,107 @@ Module for controlling Jenkins
 
         jenkins:
           api_key: peWcBiMOS9HrZG15peWcBiMOS9HrZG15
-'''
+"""
 
 # Import Python libs
 from __future__ import absolute_import, print_function, unicode_literals
+
 import logging
 
+import salt.utils.files
+
 # Import Salt libs
 import salt.utils.stringutils
 
+# Import 3rd-party libs
+# pylint: disable=import-error,no-name-in-module,redefined-builtin
+from salt.exceptions import CommandExecutionError, SaltInvocationError
+
 try:
     import jenkins
+
     HAS_JENKINS = True
 except ImportError:
     HAS_JENKINS = False
 
-import salt.utils.files
 
-# Import 3rd-party libs
-# pylint: disable=import-error,no-name-in-module,redefined-builtin
-from salt.exceptions import CommandExecutionError, SaltInvocationError
 # pylint: enable=import-error,no-name-in-module
 
 log = logging.getLogger(__name__)
 
-__virtualname__ = 'jenkins'
+__virtualname__ = "jenkins"
 
 
 def __virtual__():
-    '''
+    """
     Return virtual name of the module.
 
     :return: The virtual name of the module.
-    '''
+    """
     if HAS_JENKINS:
-        if hasattr(jenkins, 'Jenkins'):
+        if hasattr(jenkins, "Jenkins"):
             return __virtualname__
         else:
-            return (False,
-                    'The wrong Python module appears to be installed. Please '
-                    'make sure that \'python-jenkins\' is installed, not '
-                    '\'jenkins\'.')
-    return (False, 'The jenkins execution module cannot be loaded: '
-                   'python-jenkins is not installed.')
+            return (
+                False,
+                "The wrong Python module appears to be installed. Please "
+                "make sure that 'python-jenkins' is installed, not "
+                "'jenkins'.",
+            )
+    return (
+        False,
+        "The jenkins execution module cannot be loaded: "
+        "python-jenkins is not installed.",
+    )
 
 
 def _connect():
-    '''
+    """
     Return server object used to interact with Jenkins.
 
     :return: server object used to interact with Jenkins
-    '''
-    jenkins_url = __salt__['config.get']('jenkins.url') or \
-        __salt__['config.get']('jenkins:url') or \
-        __salt__['pillar.get']('jenkins.url')
+    """
+    jenkins_url = (
+        __salt__["config.get"]("jenkins.url")
+        or __salt__["config.get"]("jenkins:url")
+        or __salt__["pillar.get"]("jenkins.url")
+    )
 
-    jenkins_user = __salt__['config.get']('jenkins.user') or \
-        __salt__['config.get']('jenkins:user') or \
-        __salt__['pillar.get']('jenkins.user')
+    jenkins_user = (
+        __salt__["config.get"]("jenkins.user")
+        or __salt__["config.get"]("jenkins:user")
+        or __salt__["pillar.get"]("jenkins.user")
+    )
 
-    jenkins_password = __salt__['config.get']('jenkins.password') or \
-        __salt__['config.get']('jenkins:password') or \
-        __salt__['pillar.get']('jenkins.password')
+    jenkins_password = (
+        __salt__["config.get"]("jenkins.password")
+        or __salt__["config.get"]("jenkins:password")
+        or __salt__["pillar.get"]("jenkins.password")
+    )
 
     if not jenkins_url:
-        raise SaltInvocationError('No Jenkins URL found.')
+        raise SaltInvocationError("No Jenkins URL found.")
 
-    return jenkins.Jenkins(jenkins_url,
-                           username=jenkins_user,
-                           password=jenkins_password)
+    return jenkins.Jenkins(
+        jenkins_url, username=jenkins_user, password=jenkins_password
+    )
 
 
 def _retrieve_config_xml(config_xml, saltenv):
-    '''
+    """
     Helper to cache the config XML and raise a CommandExecutionError if we fail
     to do so. If we successfully cache the file, return the cached path.
-    '''
-    ret = __salt__['cp.cache_file'](config_xml, saltenv)
+    """
+    ret = __salt__["cp.cache_file"](config_xml, saltenv)
 
     if not ret:
-        raise CommandExecutionError('Failed to retrieve {0}'.format(config_xml))
+        raise CommandExecutionError("Failed to retrieve {0}".format(config_xml))
 
     return ret
 
 
 def run(script):
-    '''
+    """
     .. versionadded:: 2017.7.0
 
     Execute a script on the jenkins master
@@ -119,14 +134,14 @@ def run(script):
 
         salt '*' jenkins.run 'Jenkins.instance.doSafeRestart()'
 
-    '''
+    """
 
     server = _connect()
     return server.run_script(script)
 
 
 def get_version():
-    '''
+    """
     Return version of Jenkins
 
     :return: The version of Jenkins
@@ -136,7 +151,7 @@ def get_version():
     .. code-block:: bash
 
         salt '*' jenkins.get_version
-    '''
+    """
 
     server = _connect()
 
@@ -147,7 +162,7 @@ def get_version():
 
 
 def get_jobs():
-    '''
+    """
     Return the currently configured jobs.
 
     :return: The currently configured jobs.
@@ -157,7 +172,7 @@ def get_jobs():
     .. code-block:: bash
 
         salt '*' jenkins.get_jobs
-    '''
+    """
 
     server = _connect()
 
@@ -168,7 +183,7 @@ def get_jobs():
 
 
 def job_exists(name=None):
-    '''
+    """
     Check whether the job exists in configured Jenkins jobs.
 
     :param name: The name of the job is check if it exists.
@@ -180,9 +195,9 @@ def job_exists(name=None):
 
         salt '*' jenkins.job_exists jobname
 
-    '''
+    """
     if not name:
-        raise SaltInvocationError('Required parameter \'name\' is missing')
+        raise SaltInvocationError("Required parameter 'name' is missing")
 
     server = _connect()
     if server.job_exists(name):
@@ -192,7 +207,7 @@ def job_exists(name=None):
 
 
 def get_job_info(name=None):
-    '''
+    """
     Return information about the Jenkins job.
 
     :param name: The name of the job is check if it exists.
@@ -204,14 +219,14 @@ def get_job_info(name=None):
 
         salt '*' jenkins.get_job_info jobname
 
-    '''
+    """
     if not name:
-        raise SaltInvocationError('Required parameter \'name\' is missing')
+        raise SaltInvocationError("Required parameter 'name' is missing")
 
     server = _connect()
 
     if not job_exists(name):
-        raise CommandExecutionError('Job \'{0}\' does not exist'.format(name))
+        raise CommandExecutionError("Job '{0}' does not exist".format(name))
 
     job_info = server.get_job_info(name)
     if job_info:
@@ -220,7 +235,7 @@ def get_job_info(name=None):
 
 
 def build_job(name=None, parameters=None):
-    '''
+    """
     Initiate a build for the provided job.
 
     :param name: The name of the job is check if it exists.
@@ -233,28 +248,26 @@ def build_job(name=None, parameters=None):
 
         salt '*' jenkins.build_job jobname
 
-    '''
+    """
     if not name:
-        raise SaltInvocationError('Required parameter \'name\' is missing')
+        raise SaltInvocationError("Required parameter 'name' is missing")
 
     server = _connect()
 
     if not job_exists(name):
-        raise CommandExecutionError('Job \'{0}\' does not exist.'.format(name))
+        raise CommandExecutionError("Job '{0}' does not exist.".format(name))
 
     try:
         server.build_job(name, parameters)
     except jenkins.JenkinsException as err:
         raise CommandExecutionError(
-            'Encountered error building job \'{0}\': {1}'.format(name, err)
+            "Encountered error building job '{0}': {1}".format(name, err)
         )
     return True
 
 
-def create_job(name=None,
-               config_xml=None,
-               saltenv='base'):
-    '''
+def create_job(name=None, config_xml=None, saltenv="base"):
+    """
     Return the configuration file.
 
     :param name: The name of the job is check if it exists.
@@ -270,12 +283,12 @@ def create_job(name=None,
 
         salt '*' jenkins.create_job jobname config_xml='salt://jenkins/config.xml'
 
-    '''
+    """
     if not name:
-        raise SaltInvocationError('Required parameter \'name\' is missing')
+        raise SaltInvocationError("Required parameter 'name' is missing")
 
     if job_exists(name):
-        raise CommandExecutionError('Job \'{0}\' already exists'.format(name))
+        raise CommandExecutionError("Job '{0}' already exists".format(name))
 
     if not config_xml:
         config_xml = jenkins.EMPTY_CONFIG_XML
@@ -290,15 +303,13 @@ def create_job(name=None,
         server.create_job(name, config_xml)
     except jenkins.JenkinsException as err:
         raise CommandExecutionError(
-            'Encountered error creating job \'{0}\': {1}'.format(name, err)
+            "Encountered error creating job '{0}': {1}".format(name, err)
         )
     return config_xml
 
 
-def update_job(name=None,
-               config_xml=None,
-               saltenv='base'):
-    '''
+def update_job(name=None, config_xml=None, saltenv="base"):
+    """
     Return the updated configuration file.
 
     :param name: The name of the job is check if it exists.
@@ -314,9 +325,9 @@ def update_job(name=None,
 
         salt '*' jenkins.update_job jobname config_xml='salt://jenkins/config.xml'
 
-    '''
+    """
     if not name:
-        raise SaltInvocationError('Required parameter \'name\' is missing')
+        raise SaltInvocationError("Required parameter 'name' is missing")
 
     if not config_xml:
         config_xml = jenkins.EMPTY_CONFIG_XML
@@ -331,13 +342,13 @@ def update_job(name=None,
         server.reconfig_job(name, config_xml)
     except jenkins.JenkinsException as err:
         raise CommandExecutionError(
-            'Encountered error updating job \'{0}\': {1}'.format(name, err)
+            "Encountered error updating job '{0}': {1}".format(name, err)
         )
     return config_xml
 
 
 def delete_job(name=None):
-    '''
+    """
     Return true is job is deleted successfully.
 
     :param name: The name of the job to delete.
@@ -349,26 +360,26 @@ def delete_job(name=None):
 
         salt '*' jenkins.delete_job jobname
 
-    '''
+    """
     if not name:
-        raise SaltInvocationError('Required parameter \'name\' is missing')
+        raise SaltInvocationError("Required parameter 'name' is missing")
 
     server = _connect()
 
     if not job_exists(name):
-        raise CommandExecutionError('Job \'{0}\' does not exist'.format(name))
+        raise CommandExecutionError("Job '{0}' does not exist".format(name))
 
     try:
         server.delete_job(name)
     except jenkins.JenkinsException as err:
         raise CommandExecutionError(
-            'Encountered error deleting job \'{0}\': {1}'.format(name, err)
+            "Encountered error deleting job '{0}': {1}".format(name, err)
         )
     return True
 
 
 def enable_job(name=None):
-    '''
+    """
     Return true is job is enabled successfully.
 
     :param name: The name of the job to enable.
@@ -380,26 +391,26 @@ def enable_job(name=None):
 
         salt '*' jenkins.enable_job jobname
 
-    '''
+    """
     if not name:
-        raise SaltInvocationError('Required parameter \'name\' is missing')
+        raise SaltInvocationError("Required parameter 'name' is missing")
 
     server = _connect()
 
     if not job_exists(name):
-        raise CommandExecutionError('Job \'{0}\' does not exist'.format(name))
+        raise CommandExecutionError("Job '{0}' does not exist".format(name))
 
     try:
         server.enable_job(name)
     except jenkins.JenkinsException as err:
         raise CommandExecutionError(
-            'Encountered error enabling job \'{0}\': {1}'.format(name, err)
+            "Encountered error enabling job '{0}': {1}".format(name, err)
         )
     return True
 
 
 def disable_job(name=None):
-    '''
+    """
     Return true is job is disabled successfully.
 
     :param name: The name of the job to disable.
@@ -411,27 +422,27 @@ def disable_job(name=None):
 
         salt '*' jenkins.disable_job jobname
 
-    '''
+    """
 
     if not name:
-        raise SaltInvocationError('Required parameter \'name\' is missing')
+        raise SaltInvocationError("Required parameter 'name' is missing")
 
     server = _connect()
 
     if not job_exists(name):
-        raise CommandExecutionError('Job \'{0}\' does not exist'.format(name))
+        raise CommandExecutionError("Job '{0}' does not exist".format(name))
 
     try:
         server.disable_job(name)
     except jenkins.JenkinsException as err:
         raise CommandExecutionError(
-            'Encountered error disabling job \'{0}\': {1}'.format(name, err)
+            "Encountered error disabling job '{0}': {1}".format(name, err)
         )
     return True
 
 
 def job_status(name=None):
-    '''
+    """
     Return the current status, enabled or disabled, of the job.
 
     :param name: The name of the job to return status for
@@ -443,21 +454,21 @@ def job_status(name=None):
 
         salt '*' jenkins.job_status jobname
 
-    '''
+    """
 
     if not name:
-        raise SaltInvocationError('Required parameter \'name\' is missing')
+        raise SaltInvocationError("Required parameter 'name' is missing")
 
     server = _connect()
 
     if not job_exists(name):
-        raise CommandExecutionError('Job \'{0}\' does not exist'.format(name))
+        raise CommandExecutionError("Job '{0}' does not exist".format(name))
 
-    return server.get_job_info('empty')['buildable']
+    return server.get_job_info("empty")["buildable"]
 
 
 def get_job_config(name=None):
-    '''
+    """
     Return the current job configuration for the provided job.
 
     :param name: The name of the job to return the configuration for.
@@ -469,22 +480,22 @@ def get_job_config(name=None):
 
         salt '*' jenkins.get_job_config jobname
 
-    '''
+    """
 
     if not name:
-        raise SaltInvocationError('Required parameter \'name\' is missing')
+        raise SaltInvocationError("Required parameter 'name' is missing")
 
     server = _connect()
 
     if not job_exists(name):
-        raise CommandExecutionError('Job \'{0}\' does not exist'.format(name))
+        raise CommandExecutionError("Job '{0}' does not exist".format(name))
 
     job_info = server.get_job_config(name)
     return job_info
 
 
 def plugin_installed(name):
-    '''
+    """
     .. versionadded:: 2016.11.0
 
     Return if the plugin is installed for the provided plugin name.
@@ -498,7 +509,7 @@ def plugin_installed(name):
 
         salt '*' jenkins.plugin_installed pluginName
 
-    '''
+    """
 
     server = _connect()
     plugins = server.get_plugins()
