@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 The Saltutil module is used to manage the state of the salt minion itself. It
 is used to manage minion modules as well as automate updates to the salt
@@ -6,9 +5,7 @@ minion.
 
 :depends:   - esky Python module for update functionality
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import python libs
 import copy
 import fnmatch
 import logging
@@ -17,8 +14,8 @@ import shutil
 import signal
 import sys
 import time
+import urllib.error
 
-# Import salt libs
 import salt
 import salt.client
 import salt.client.ssh.client
@@ -45,12 +42,6 @@ from salt.exceptions import (
     SaltReqTimeoutError,
 )
 
-# pylint: disable=no-name-in-module
-from salt.ext import six
-from salt.ext.six.moves.urllib.error import URLError
-
-# Import 3rd-party libs
-# pylint: disable=import-error
 try:
     import esky
     from esky import EskyVersionError
@@ -87,15 +78,17 @@ def _get_top_file_envs():
     try:
         return __context__["saltutil._top_file_envs"]
     except KeyError:
+        st_ = salt.state.HighState(__opts__, initial_pillar=__pillar__.value())
         try:
-            st_ = salt.state.HighState(__opts__, initial_pillar=__pillar__)
             top = st_.get_top()
             if top:
                 envs = list(st_.top_matches(top).keys()) or "base"
             else:
                 envs = "base"
         except SaltRenderError as exc:
-            raise CommandExecutionError("Unable to render top file(s): {0}".format(exc))
+            raise CommandExecutionError("Unable to render top file(s): {}".format(exc))
+        finally:
+            st_.client.destroy()
         __context__["saltutil._top_file_envs"] = envs
         return envs
 
@@ -106,7 +99,7 @@ def _sync(form, saltenv=None, extmod_whitelist=None, extmod_blacklist=None):
     """
     if saltenv is None:
         saltenv = _get_top_file_envs()
-    if isinstance(saltenv, six.string_types):
+    if isinstance(saltenv, str):
         saltenv = saltenv.split(",")
     ret, touched = salt.utils.extmods.sync(
         __opts__,
@@ -170,8 +163,8 @@ def update(version=None):
     if not version:
         try:
             version = app.find_update()
-        except URLError as exc:
-            ret["_error"] = "Could not connect to update_url. Error: {0}".format(exc)
+        except urllib.error.URLError as exc:
+            ret["_error"] = "Could not connect to update_url. Error: {}".format(exc)
             return ret
     if not version:
         ret["_error"] = "No updates available"
@@ -179,21 +172,21 @@ def update(version=None):
     try:
         app.fetch_version(version)
     except EskyVersionError as exc:
-        ret["_error"] = "Unable to fetch version {0}. Error: {1}".format(version, exc)
+        ret["_error"] = "Unable to fetch version {}. Error: {}".format(version, exc)
         return ret
     try:
         app.install_version(version)
     except EskyVersionError as exc:
-        ret["_error"] = "Unable to install version {0}. Error: {1}".format(version, exc)
+        ret["_error"] = "Unable to install version {}. Error: {}".format(version, exc)
         return ret
     try:
         app.cleanup()
     except Exception as exc:  # pylint: disable=broad-except
-        ret["_error"] = "Unable to cleanup. Error: {0}".format(exc)
+        ret["_error"] = "Unable to cleanup. Error: {}".format(exc)
     restarted = {}
     for service in __opts__["update_restart_services"]:
         restarted[service] = __salt__["service.restart"](service)
-    ret["comment"] = "Updated from {0} to {1}".format(oldversion, version)
+    ret["comment"] = "Updated from {} to {}".format(oldversion, version)
     ret["restarted"] = restarted
     return ret
 
@@ -1371,7 +1364,7 @@ def find_cached_job(jid):
     """
     serial = salt.payload.Serial(__opts__)
     proc_dir = os.path.join(__opts__["cachedir"], "minion_jobs")
-    job_dir = os.path.join(proc_dir, six.text_type(jid))
+    job_dir = os.path.join(proc_dir, str(jid))
     if not os.path.isdir(job_dir):
         if not __opts__.get("cache_jobs"):
             return (
@@ -1379,7 +1372,7 @@ def find_cached_job(jid):
                 " enable cache_jobs on this minion"
             )
         else:
-            return "Local jobs cache directory {0} not found".format(job_dir)
+            return "Local jobs cache directory {} not found".format(job_dir)
     path = os.path.join(job_dir, "return.p")
     with salt.utils.files.fopen(path, "rb") as fp_:
         buf = fp_.read()
@@ -1424,15 +1417,15 @@ def signal_job(jid, sig):
                 if HAS_PSUTIL is False and "child_pids" in data:
                     for pid in data["child_pids"]:
                         os.kill(int(pid), sig)
-                return "Signal {0} sent to job {1} at pid {2}".format(
+                return "Signal {} sent to job {} at pid {}".format(
                     int(sig), jid, data["pid"]
                 )
             except OSError:
-                path = os.path.join(__opts__["cachedir"], "proc", six.text_type(jid))
+                path = os.path.join(__opts__["cachedir"], "proc", str(jid))
                 if os.path.isfile(path):
                     os.remove(path)
                 return (
-                    "Job {0} was not running and job data has been " " cleaned up"
+                    "Job {} was not running and job data has been " " cleaned up"
                 ).format(jid)
     return ""
 
@@ -1653,19 +1646,21 @@ def cmd(
         salt '*' saltutil.cmd
     """
     cfgfile = __opts__["conf_file"]
-    client = _get_ssh_or_api_client(cfgfile, ssh)
-    fcn_ret = _exec(client, tgt, fun, arg, timeout, tgt_type, ret, kwarg, **kwargs)
+    with _get_ssh_or_api_client(cfgfile, ssh) as client:
+        fcn_ret = _exec(client, tgt, fun, arg, timeout, tgt_type, ret, kwarg, **kwargs)
     # if return is empty, we may have not used the right conf,
     # try with the 'minion relative master configuration counter part
     # if available
-    master_cfgfile = "{0}master".format(cfgfile[:-6])  # remove 'minion'
+    master_cfgfile = "{}master".format(cfgfile[:-6])  # remove 'minion'
     if (
         not fcn_ret
-        and cfgfile.endswith("{0}{1}".format(os.path.sep, "minion"))
+        and cfgfile.endswith("{}{}".format(os.path.sep, "minion"))
         and os.path.exists(master_cfgfile)
     ):
-        client = _get_ssh_or_api_client(master_cfgfile, ssh)
-        fcn_ret = _exec(client, tgt, fun, arg, timeout, tgt_type, ret, kwarg, **kwargs)
+        with _get_ssh_or_api_client(master_cfgfile, ssh) as client:
+            fcn_ret = _exec(
+                client, tgt, fun, arg, timeout, tgt_type, ret, kwarg, **kwargs
+            )
 
     return fcn_ret
 
@@ -1780,7 +1775,7 @@ def wheel(name, *args, **kwargs):
         Any positional arguments to pass to the wheel function. A common example
         of this would be the ``match`` arg needed for key functions.
 
-        .. versionadded:: v2015.8.11
+        .. versionadded:: 2015.8.11
 
     kwargs
         Any keyword arguments to pass to the wheel function
@@ -1815,7 +1810,7 @@ def wheel(name, *args, **kwargs):
     # the "normal" kwargs structure, which at this point contains __pub_x keys.
     pub_data = {}
     valid_kwargs = {}
-    for key, val in six.iteritems(kwargs):
+    for key, val in kwargs.items():
         if key.startswith("__"):
             pub_data[key] = val
         else:
@@ -1854,7 +1849,7 @@ def wheel(name, *args, **kwargs):
 
 # this is the only way I could figure out how to get the REAL file_roots
 # __opt__['file_roots'] is set to  __opt__['pillar_root']
-class _MMinion(object):
+class _MMinion:
     def __new__(cls, saltenv, reload_env=False):
         # this is to break out of salt.loaded.int and make this a true singleton
         # hack until https://github.com/saltstack/salt/pull/10273 is resolved
