@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Package support for openSUSE via the zypper package manager
 
@@ -12,19 +11,18 @@ Package support for openSUSE via the zypper package manager
 
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
+import configparser
 import datetime
 import fnmatch
 import logging
 import os
 import re
 import time
+import urllib.parse
 from xml.dom import minidom as dom
 from xml.parsers.expat import ExpatError
 
-# Import salt libs
 import salt.utils.data
 import salt.utils.environment
 import salt.utils.event
@@ -35,24 +33,16 @@ import salt.utils.pkg
 import salt.utils.pkg.rpm
 import salt.utils.stringutils
 import salt.utils.systemd
+import salt.utils.versions
 from salt.exceptions import CommandExecutionError, MinionError, SaltInvocationError
-
-# Import 3rd-party libs
-# pylint: disable=import-error,redefined-builtin,no-name-in-module
-from salt.ext import six
-from salt.ext.six.moves import configparser
-from salt.ext.six.moves.urllib.parse import urlparse as _urlparse
 from salt.utils.versions import LooseVersion
 
-# pylint: enable=import-error,redefined-builtin,no-name-in-module
-
-
 log = logging.getLogger(__name__)
 
 HAS_ZYPP = False
 ZYPP_HOME = "/etc/zypp"
-LOCKS = "{0}/locks".format(ZYPP_HOME)
-REPOS = "{0}/repos.d".format(ZYPP_HOME)
+LOCKS = "{}/locks".format(ZYPP_HOME)
+REPOS = "{}/repos.d".format(ZYPP_HOME)
 DEFAULT_PRIORITY = 99
 PKG_ARCH_SEPARATOR = "."
 
@@ -75,7 +65,7 @@ def __virtual__():
     return __virtualname__
 
 
-class _Zypper(object):
+class _Zypper:
     """
     Zypper parallel caller.
     Validates the result and either raises an exception or reports an error.
@@ -339,7 +329,7 @@ class _Zypper(object):
                             attrs=["pid", "name", "cmdline", "create_time"],
                         )
                         data["cmdline"] = " ".join(data["cmdline"])
-                        data["info"] = "Blocking process created at {0}.".format(
+                        data["info"] = "Blocking process created at {}.".format(
                             datetime.datetime.utcfromtimestamp(
                                 data["create_time"]
                             ).isoformat()
@@ -347,7 +337,7 @@ class _Zypper(object):
                         data["success"] = True
                 except Exception as err:  # pylint: disable=broad-except
                     data = {
-                        "info": "Unable to retrieve information about blocking process: {0}".format(
+                        "info": "Unable to retrieve information about blocking process: {}".format(
                             err.message
                         ),
                         "success": False,
@@ -382,7 +372,7 @@ class _Zypper(object):
             )
         if self.error_msg and not self.__no_raise and not self.__ignore_repo_failure:
             raise CommandExecutionError(
-                "Zypper command failure: {0}".format(self.error_msg)
+                "Zypper command failure: {}".format(self.error_msg)
             )
 
         return (
@@ -397,7 +387,7 @@ class _Zypper(object):
 __zypper__ = _Zypper()
 
 
-class Wildcard(object):
+class Wildcard:
     """
     .. versionadded:: 2017.7.0
 
@@ -439,7 +429,7 @@ class Wildcard(object):
                     for vrs in self._get_scope_versions(self._get_available_versions())
                 ]
             )
-            return versions and "{0}{1}".format(self._op or "", versions[-1]) or None
+            return versions and "{}{}".format(self._op or "", versions[-1]) or None
 
     def _get_available_versions(self):
         """
@@ -451,17 +441,15 @@ class Wildcard(object):
         ).getElementsByTagName("solvable")
         if not solvables:
             raise CommandExecutionError(
-                "No packages found matching '{0}'".format(self.name)
+                "No packages found matching '{}'".format(self.name)
             )
 
         return sorted(
-            set(
-                [
-                    slv.getAttribute(self._attr_solvable_version)
-                    for slv in solvables
-                    if slv.getAttribute(self._attr_solvable_version)
-                ]
-            )
+            {
+                slv.getAttribute(self._attr_solvable_version)
+                for slv in solvables
+                if slv.getAttribute(self._attr_solvable_version)
+            }
         )
 
     def _get_scope_versions(self, pkg_versions):
@@ -489,7 +477,7 @@ class Wildcard(object):
         self._op = version.replace(exact_version, "") or None
         if self._op and self._op not in self.Z_OP:
             raise CommandExecutionError(
-                'Zypper do not supports operator "{0}".'.format(self._op)
+                'Zypper do not supports operator "{}".'.format(self._op)
             )
         self.version = exact_version
 
@@ -539,15 +527,10 @@ def list_upgrades(refresh=True, root=None, **kwargs):
     cmd = ["list-updates"]
     if "fromrepo" in kwargs:
         repos = kwargs["fromrepo"]
-        if isinstance(repos, six.string_types):
+        if isinstance(repos, str):
             repos = [repos]
         for repo in repos:
-            cmd.extend(
-                [
-                    "--repo",
-                    repo if isinstance(repo, six.string_types) else six.text_type(repo),
-                ]
-            )
+            cmd.extend(["--repo", repo if isinstance(repo, str) else str(repo)])
         log.debug("Targeting repos: %s", repos)
     for update_node in (
         __zypper__(root=root).nolock.xml.call(*cmd).getElementsByTagName("update")
@@ -591,7 +574,7 @@ def info_installed(*names, **kwargs):
     :param root:
         Operate on a different root directory.
 
-    CLI example:
+    CLI Example:
 
     .. code-block:: bash
 
@@ -610,7 +593,7 @@ def info_installed(*names, **kwargs):
         for _nfo in pkg_nfo:
             t_nfo = dict()
             # Translate dpkg-specific keys to a common structure
-            for key, value in six.iteritems(_nfo):
+            for key, value in _nfo.items():
                 if key == "source_rpm":
                     t_nfo["source"] = value
                 else:
@@ -634,7 +617,7 @@ def info_available(*names, **kwargs):
     root
         operate on a different root directory.
 
-    CLI example:
+    CLI Example:
 
     .. code-block:: bash
 
@@ -727,7 +710,7 @@ def latest_version(*names, **kwargs):
     root
         operate on a different root directory.
 
-    CLI example:
+    CLI Example:
 
     .. code-block:: bash
 
@@ -825,6 +808,15 @@ def version_cmp(ver1, ver2, ignore_epoch=False, **kwargs):
     return __salt__["lowpkg.version_cmp"](ver1, ver2, ignore_epoch=ignore_epoch)
 
 
+def _list_pkgs_from_context(versions_as_list, contextkey, attr):
+    """
+    Use pkg list from __context__
+    """
+    return __salt__["pkg_resource.format_pkg_list"](
+        __context__[contextkey], versions_as_list, attr
+    )
+
+
 def list_pkgs(versions_as_list=False, root=None, includes=None, **kwargs):
     """
     List the packages currently installed as a dict. By default, the dict
@@ -888,86 +880,86 @@ def list_pkgs(versions_as_list=False, root=None, includes=None, **kwargs):
     # inclusion types are passed
     contextkey = "pkg.list_pkgs_{}_{}".format(root, includes)
 
-    if contextkey not in __context__:
-        ret = {}
-        cmd = ["rpm"]
-        if root:
-            cmd.extend(["--root", root])
-        cmd.extend(
-            [
-                "-qa",
-                "--queryformat",
-                salt.utils.pkg.rpm.QUERYFORMAT.replace("%{REPOID}", "(none)") + "\n",
-            ]
-        )
-        output = __salt__["cmd.run"](cmd, python_shell=False, output_loglevel="trace")
-        for line in output.splitlines():
-            pkginfo = salt.utils.pkg.rpm.parse_pkginfo(
-                line, osarch=__grains__["osarch"]
-            )
-            if pkginfo:
-                # see rpm version string rules available at https://goo.gl/UGKPNd
-                pkgver = pkginfo.version
-                epoch = None
-                release = None
-                if ":" in pkgver:
-                    epoch, pkgver = pkgver.split(":", 1)
-                if "-" in pkgver:
-                    pkgver, release = pkgver.split("-", 1)
-                all_attr = {
-                    "epoch": epoch,
-                    "version": pkgver,
-                    "release": release,
-                    "arch": pkginfo.arch,
-                    "install_date": pkginfo.install_date,
-                    "install_date_time_t": pkginfo.install_date_time_t,
-                }
-                __salt__["pkg_resource.add_pkg"](ret, pkginfo.name, all_attr)
+    if contextkey in __context__ and kwargs.get("use_context", True):
+        return _list_pkgs_from_context(versions_as_list, contextkey, attr)
 
-        _ret = {}
-        for pkgname in ret:
-            # Filter out GPG public keys packages
-            if pkgname.startswith("gpg-pubkey"):
-                continue
-            _ret[pkgname] = sorted(ret[pkgname], key=lambda d: d["version"])
+    ret = {}
+    cmd = ["rpm"]
+    if root:
+        cmd.extend(["--root", root])
+    cmd.extend(
+        [
+            "-qa",
+            "--queryformat",
+            salt.utils.pkg.rpm.QUERYFORMAT.replace("%{REPOID}", "(none)") + "\n",
+        ]
+    )
+    output = __salt__["cmd.run"](cmd, python_shell=False, output_loglevel="trace")
+    for line in output.splitlines():
+        pkginfo = salt.utils.pkg.rpm.parse_pkginfo(line, osarch=__grains__["osarch"])
+        if pkginfo:
+            # see rpm version string rules available at https://goo.gl/UGKPNd
+            pkgver = pkginfo.version
+            epoch = None
+            release = None
+            if ":" in pkgver:
+                epoch, pkgver = pkgver.split(":", 1)
+            if "-" in pkgver:
+                pkgver, release = pkgver.split("-", 1)
+            all_attr = {
+                "epoch": epoch,
+                "version": pkgver,
+                "release": release,
+                "arch": pkginfo.arch,
+                "install_date": pkginfo.install_date,
+                "install_date_time_t": pkginfo.install_date_time_t,
+            }
+            __salt__["pkg_resource.add_pkg"](ret, pkginfo.name, all_attr)
 
-        for include in includes:
-            if include == "product":
-                products = list_products(all=False, root=root)
-                for product in products:
-                    extended_name = "{}:{}".format(include, product["name"])
-                    _ret[extended_name] = [
-                        {
-                            "epoch": product["epoch"],
-                            "version": product["version"],
-                            "release": product["release"],
-                            "arch": product["arch"],
-                            "install_date": None,
-                            "install_date_time_t": None,
-                        }
-                    ]
-            if include in ("pattern", "patch"):
-                if include == "pattern":
-                    elements = list_installed_patterns(root=root)
-                elif include == "patch":
-                    elements = list_installed_patches(root=root)
-                else:
-                    elements = []
-                for element in elements:
-                    extended_name = "{}:{}".format(include, element)
-                    info = info_available(extended_name, refresh=False, root=root)
-                    _ret[extended_name] = [
-                        {
-                            "epoch": None,
-                            "version": info[element]["version"],
-                            "release": None,
-                            "arch": info[element]["arch"],
-                            "install_date": None,
-                            "install_date_time_t": None,
-                        }
-                    ]
+    _ret = {}
+    for pkgname in ret:
+        # Filter out GPG public keys packages
+        if pkgname.startswith("gpg-pubkey"):
+            continue
+        _ret[pkgname] = sorted(ret[pkgname], key=lambda d: d["version"])
 
-        __context__[contextkey] = _ret
+    for include in includes:
+        if include == "product":
+            products = list_products(all=False, root=root)
+            for product in products:
+                extended_name = "{}:{}".format(include, product["name"])
+                _ret[extended_name] = [
+                    {
+                        "epoch": product["epoch"],
+                        "version": product["version"],
+                        "release": product["release"],
+                        "arch": product["arch"],
+                        "install_date": None,
+                        "install_date_time_t": None,
+                    }
+                ]
+        if include in ("pattern", "patch"):
+            if include == "pattern":
+                elements = list_installed_patterns(root=root)
+            elif include == "patch":
+                elements = list_installed_patches(root=root)
+            else:
+                elements = []
+            for element in elements:
+                extended_name = "{}:{}".format(include, element)
+                info = info_available(extended_name, refresh=False, root=root)
+                _ret[extended_name] = [
+                    {
+                        "epoch": None,
+                        "version": info[element]["version"],
+                        "release": None,
+                        "arch": info[element]["arch"],
+                        "install_date": None,
+                        "install_date_time_t": None,
+                    }
+                ]
+
+    __context__[contextkey] = _ret
 
     return __salt__["pkg_resource.format_pkg_list"](
         __context__[contextkey], versions_as_list, attr
@@ -1033,9 +1025,7 @@ def list_repo_pkgs(*args, **kwargs):
     fromrepo = kwargs.pop("fromrepo", "") or ""
     ret = {}
 
-    targets = [
-        arg if isinstance(arg, six.string_types) else six.text_type(arg) for arg in args
-    ]
+    targets = [arg if isinstance(arg, str) else str(arg) for arg in args]
 
     def _is_match(pkgname):
         """
@@ -1124,7 +1114,7 @@ def _get_repo_info(alias, repos_cfg=None, root=None):
     try:
         meta = dict((repos_cfg or _get_configured_repos(root=root)).items(alias))
         meta["alias"] = alias
-        for key, val in six.iteritems(meta):
+        for key, val in meta.items():
             if val in ["0", "1"]:
                 meta[key] = int(meta[key]) == 1
             elif val == "NONE":
@@ -1197,7 +1187,7 @@ def del_repo(repo, root=None):
                     "message": msg[0].childNodes[0].nodeValue,
                 }
 
-    raise CommandExecutionError("Repository '{0}' not found.".format(repo))
+    raise CommandExecutionError("Repository '{}' not found.".format(repo))
 
 
 def mod_repo(repo, **kwargs):
@@ -1252,13 +1242,13 @@ def mod_repo(repo, **kwargs):
         url = kwargs.get("url", kwargs.get("mirrorlist", kwargs.get("baseurl")))
         if not url:
             raise CommandExecutionError(
-                "Repository '{0}' not found, and neither 'baseurl' nor "
+                "Repository '{}' not found, and neither 'baseurl' nor "
                 "'mirrorlist' was specified".format(repo)
             )
 
-        if not _urlparse(url).scheme:
+        if not urllib.parse.urlparse(url).scheme:
             raise CommandExecutionError(
-                "Repository '{0}' not found and URL for baseurl/mirrorlist "
+                "Repository '{}' not found and URL for baseurl/mirrorlist "
                 "is malformed".format(repo)
             )
 
@@ -1267,9 +1257,9 @@ def mod_repo(repo, **kwargs):
             repo_meta = _get_repo_info(alias, repos_cfg=repos_cfg, root=root)
 
             # Complete user URL, in case it is not
-            new_url = _urlparse(url)
+            new_url = urllib.parse.urlparse(url)
             if not new_url.path:
-                new_url = _urlparse.ParseResult(
+                new_url = urllib.parse.urlparse.ParseResult(
                     scheme=new_url.scheme,  # pylint: disable=E1123
                     netloc=new_url.netloc,
                     path="/",
@@ -1277,11 +1267,11 @@ def mod_repo(repo, **kwargs):
                     query=new_url.query,
                     fragment=new_url.fragment,
                 )
-            base_url = _urlparse(repo_meta["baseurl"])
+            base_url = urllib.parse.urlparse(repo_meta["baseurl"])
 
             if new_url == base_url:
                 raise CommandExecutionError(
-                    "Repository '{0}' already exists as '{1}'.".format(repo, alias)
+                    "Repository '{}' already exists as '{}'.".format(repo, alias)
                 )
 
         # Add new repo
@@ -1291,7 +1281,7 @@ def mod_repo(repo, **kwargs):
         repos_cfg = _get_configured_repos(root=root)
         if repo not in repos_cfg.sections():
             raise CommandExecutionError(
-                "Failed add new repository '{0}' for unspecified reason. "
+                "Failed add new repository '{}' for unspecified reason. "
                 "Please check zypper logs.".format(repo)
             )
         added = True
@@ -1327,12 +1317,10 @@ def mod_repo(repo, **kwargs):
         cmd_opt.append(kwargs["gpgcheck"] and "--gpgcheck" or "--no-gpgcheck")
 
     if "priority" in kwargs:
-        cmd_opt.append(
-            "--priority={0}".format(kwargs.get("priority", DEFAULT_PRIORITY))
-        )
+        cmd_opt.append("--priority={}".format(kwargs.get("priority", DEFAULT_PRIORITY)))
 
     if "humanname" in kwargs:
-        cmd_opt.append("--name='{0}'".format(kwargs.get("humanname")))
+        cmd_opt.append("--name='{}'".format(kwargs.get("humanname")))
 
     if kwargs.get("gpgautoimport") is True:
         global_cmd_opt.append("--gpg-auto-import-keys")
@@ -1589,7 +1577,7 @@ def install(
 
     if pkg_type == "repository":
         targets = []
-        for param, version_num in six.iteritems(pkg_params):
+        for param, version_num in pkg_params.items():
             if version_num is None:
                 log.debug("targeting package: %s", param)
                 targets.append(param)
@@ -1597,7 +1585,7 @@ def install(
                 prefix, verstr = salt.utils.pkg.split_comparison(version_num)
                 if not prefix:
                     prefix = "="
-                target = "{0}{1}{2}".format(param, prefix, verstr)
+                target = "{}{}{}".format(param, prefix, verstr)
                 log.debug("targeting package: %s", target)
                 targets.append(target)
     elif pkg_type == "advisory":
@@ -1606,7 +1594,7 @@ def install(
         for advisory_id in pkg_params:
             if advisory_id not in cur_patches:
                 raise CommandExecutionError(
-                    'Advisory id "{0}" not found'.format(advisory_id)
+                    'Advisory id "{}" not found'.format(advisory_id)
                 )
             else:
                 # If we add here the `patch:` prefix, the
@@ -1703,7 +1691,7 @@ def install(
 
     if errors:
         raise CommandExecutionError(
-            "Problem encountered {0} package(s)".format(
+            "Problem encountered {} package(s)".format(
                 "downloading" if downloadonly else "installing"
             ),
             info={"errors": errors, "changes": ret},
@@ -1797,7 +1785,7 @@ def upgrade(
         cmd_update.append("--dry-run")
 
     if fromrepo:
-        if isinstance(fromrepo, six.string_types):
+        if isinstance(fromrepo, str):
             fromrepo = [fromrepo]
         for repo in fromrepo:
             cmd_update.extend(["--from" if dist_upgrade else "--repo", repo])
@@ -2052,7 +2040,7 @@ def list_locks(root=None):
                         )
                 if lock.get("solvable_name"):
                     locks[lock.pop("solvable_name")] = lock
-    except IOError:
+    except OSError:
         pass
     except Exception:  # pylint: disable=broad-except
         log.warning("Detected a problem when accessing {}".format(_locks))
@@ -2089,10 +2077,71 @@ def clean_locks(root=None):
     return out
 
 
-def remove_lock(packages, root=None, **kwargs):  # pylint: disable=unused-argument
+def unhold(name=None, pkgs=None, **kwargs):
     """
+    .. versionadded:: 3003
+
+    Remove a package hold.
+
+    name
+        A package name to unhold, or a comma-separated list of package names to
+        unhold.
+
+    pkgs
+        A list of packages to unhold.  The ``name`` parameter will be ignored if
+        this option is passed.
+
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' pkg.unhold <package name>
+        salt '*' pkg.unhold <package1>,<package2>,<package3>
+        salt '*' pkg.unhold pkgs='["foo", "bar"]'
+    """
+    ret = {}
+    if not name and not pkgs:
+        raise CommandExecutionError("Name or packages must be specified.")
+
+    targets = []
+    if pkgs:
+        for pkg in salt.utils.data.repack_dictlist(pkgs):
+            targets.append(pkg)
+    else:
+        targets.append(name)
+
+    locks = list_locks()
+    removed = []
+    missing = []
+
+    for target in targets:
+        ret[target] = {"name": target, "changes": {}, "result": True, "comment": ""}
+        if locks.get(target):
+            removed.append(target)
+            ret[target]["changes"]["new"] = ""
+            ret[target]["changes"]["old"] = "hold"
+            ret[target]["comment"] = "Package {} is no longer held.".format(target)
+        else:
+            missing.append(target)
+            ret[target]["comment"] = "Package {} was already unheld.".format(target)
+
+    if removed:
+        __zypper__.call("rl", *removed)
+
+    return ret
+
+
+def remove_lock(name, root=None, **kwargs):
+    """
+    .. deprecated:: 3003
+        This function is deprecated. Please use ``unhold()`` instead.
+
     Remove specified package lock.
 
+    name
+        A package name, or a comma-separated list of package names.
+
     root
         operate on a different root directory.
 
@@ -2102,12 +2151,14 @@ def remove_lock(packages, root=None, **kwargs):  # pylint: disable=unused-argume
 
         salt '*' pkg.remove_lock <package name>
         salt '*' pkg.remove_lock <package1>,<package2>,<package3>
-        salt '*' pkg.remove_lock pkgs='["foo", "bar"]'
     """
 
+    salt.utils.versions.warn_until(
+        "Phosphorus", "This function is deprecated. Please use unhold() instead."
+    )
     locks = list_locks(root)
     try:
-        packages = list(__salt__["pkg_resource.parse_targets"](packages)[0].keys())
+        packages = list(__salt__["pkg_resource.parse_targets"](name)[0].keys())
     except MinionError as exc:
         raise CommandExecutionError(exc)
 
@@ -2125,8 +2176,66 @@ def remove_lock(packages, root=None, **kwargs):  # pylint: disable=unused-argume
     return {"removed": len(removed), "not_found": missing}
 
 
-def add_lock(packages, root=None, **kwargs):  # pylint: disable=unused-argument
+def hold(name=None, pkgs=None, **kwargs):
     """
+    .. versionadded:: 3003
+
+    Add a package hold.  Specify one of ``name`` and ``pkgs``.
+
+    name
+        A package name to hold, or a comma-separated list of package names to
+        hold.
+
+    pkgs
+        A list of packages to hold.  The ``name`` parameter will be ignored if
+        this option is passed.
+
+
+    CLI Example:
+
+    .. code-block:: bash
+
+        salt '*' pkg.hold <package name>
+        salt '*' pkg.hold <package1>,<package2>,<package3>
+        salt '*' pkg.hold pkgs='["foo", "bar"]'
+    """
+    ret = {}
+    if not name and not pkgs:
+        raise CommandExecutionError("Name or packages must be specified.")
+
+    targets = []
+    if pkgs:
+        for pkg in salt.utils.data.repack_dictlist(pkgs):
+            targets.append(pkg)
+    else:
+        targets.append(name)
+
+    locks = list_locks()
+    added = []
+
+    for target in targets:
+        ret[target] = {"name": target, "changes": {}, "result": True, "comment": ""}
+        if not locks.get(target):
+            added.append(target)
+            ret[target]["changes"]["new"] = "hold"
+            ret[target]["changes"]["old"] = ""
+            ret[target]["comment"] = "Package {} is now being held.".format(target)
+        else:
+            ret[target]["comment"] = "Package {} is already set to be held.".format(
+                target
+            )
+
+    if added:
+        __zypper__.call("al", *added)
+
+    return ret
+
+
+def add_lock(name, root=None, **kwargs):
+    """
+    .. deprecated:: 3003
+        This function is deprecated. Please use ``hold()`` instead.
+
     Add a package lock. Specify packages to lock by exact name.
 
     root
@@ -2138,12 +2247,14 @@ def add_lock(packages, root=None, **kwargs):  # pylint: disable=unused-argument
 
         salt '*' pkg.add_lock <package name>
         salt '*' pkg.add_lock <package1>,<package2>,<package3>
-        salt '*' pkg.add_lock pkgs='["foo", "bar"]'
     """
+    salt.utils.versions.warn_until(
+        "Phosphorus", "This function is deprecated. Please use hold() instead."
+    )
     locks = list_locks(root)
     added = []
     try:
-        packages = list(__salt__["pkg_resource.parse_targets"](packages)[0].keys())
+        packages = list(__salt__["pkg_resource.parse_targets"](name)[0].keys())
     except MinionError as exc:
         raise CommandExecutionError(exc)
 
@@ -2495,7 +2606,7 @@ def search(criteria, refresh=False, **kwargs):
         .getElementsByTagName("solvable")
     )
     if not solvables:
-        raise CommandExecutionError("No packages found matching '{0}'".format(criteria))
+        raise CommandExecutionError("No packages found matching '{}'".format(criteria))
 
     out = {}
     for solvable in solvables:
@@ -2611,7 +2722,7 @@ def download(*packages, **kwargs):
     root
         operate on a different root directory.
 
-    CLI example:
+    CLI Example:
 
     .. code-block:: bash
 
@@ -2649,13 +2760,13 @@ def download(*packages, **kwargs):
         if failed:
             pkg_ret[
                 "_error"
-            ] = "The following package(s) failed to download: {0}".format(
+            ] = "The following package(s) failed to download: {}".format(
                 ", ".join(failed)
             )
         return pkg_ret
 
     raise CommandExecutionError(
-        "Unable to download packages: {0}".format(", ".join(packages))
+        "Unable to download packages: {}".format(", ".join(packages))
     )
 
 
@@ -2668,7 +2779,7 @@ def list_downloaded(root=None, **kwargs):
     root
         operate on a different root directory.
 
-    CLI example:
+    CLI Example:
 
     .. code-block:: bash
 
@@ -2706,7 +2817,7 @@ def diff(*paths, **kwargs):
     :param path: Full path to the installed file
     :return: Difference string or raises and exception if examined file is binary.
 
-    CLI example:
+    CLI Example:
 
     .. code-block:: bash
 
@@ -2726,7 +2837,7 @@ def diff(*paths, **kwargs):
 
     if pkg_to_paths:
         local_pkgs = __salt__["pkg.download"](*pkg_to_paths.keys(), **kwargs)
-        for pkg, files in six.iteritems(pkg_to_paths):
+        for pkg, files in pkg_to_paths.items():
             for path in files:
                 ret[path] = (
                     __salt__["lowpkg.diff"](local_pkgs[pkg]["path"], path)
@@ -2903,3 +3014,27 @@ def resolve_capabilities(pkgs, refresh=False, root=None, **kwargs):
         else:
             ret.append(name)
     return ret
+
+
+def services_need_restart(root=None, **kwargs):
+    """
+    .. versionadded:: 3003
+
+    List services that use files which have been changed by the
+    package manager. It might be needed to restart them.
+
+    root
+        operate on a different root directory.
+
+    CLI Examples:
+
+    .. code-block:: bash
+
+        salt '*' pkg.services_need_restart
+    """
+    cmd = ["ps", "-sss"]
+
+    zypper_output = __zypper__(root=root).nolock.call(*cmd)
+    services = zypper_output.split()
+
+    return services
