@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 BGP Finder
 ==========
@@ -97,22 +96,15 @@ Configuration
               - flap_count
             outputter: yaml
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
-# Import salt lib
 import salt.output
-from salt.ext import six
-from salt.ext.six.moves import map
 
-# Import third party libs
 try:
     from netaddr import IPNetwork
     from netaddr import IPAddress
 
-    # pylint: disable=unused-import
-    from napalm.base import helpers as napalm_helpers
+    from napalm.base import helpers as napalm_helpers  # pylint: disable=unused-import
 
-    # pylint: enable=unused-import
     HAS_NAPALM = True
 except ImportError:
     HAS_NAPALM = False
@@ -189,7 +181,7 @@ def _compare_match(dict1, dict2):
     """
     Compare two dictionaries and return a boolean value if their values match.
     """
-    for karg, warg in six.iteritems(dict1):
+    for karg, warg in dict1.items():
         if karg in dict2 and dict2[karg] != warg:
             return False
     return True
@@ -298,7 +290,7 @@ def neighbors(*asns, **kwargs):
     # __pub args not used in this runner (yet)
     kwargs_copy = {}
     kwargs_copy.update(kwargs)
-    for karg, _ in six.iteritems(kwargs_copy):
+    for karg, _ in kwargs_copy.items():
         if karg.startswith("__pub"):
             kwargs.pop(karg)
     if not asns and not kwargs:
@@ -328,7 +320,7 @@ def neighbors(*asns, **kwargs):
         if asns:
             title_parts.append(
                 "BGP Neighbors for {asns}".format(
-                    asns=", ".join([six.text_type(asn) for asn in asns])
+                    asns=", ".join([str(asn) for asn in asns])
                 )
             )
         if neighbor_ip:
@@ -355,19 +347,21 @@ def neighbors(*asns, **kwargs):
                 )
             )
         title = "\n".join(title_parts)
-    for minion, get_bgp_neighbors_minion in six.iteritems(
-        get_bgp_neighbors_all
-    ):  # pylint: disable=too-many-nested-blocks
+    for (
+        minion,
+        get_bgp_neighbors_minion,
+    ) in get_bgp_neighbors_all.items():  # pylint: disable=too-many-nested-blocks
         if not get_bgp_neighbors_minion.get("result"):
             continue  # ignore empty or failed mines
         if device and minion != device:
             # when requested to display only the neighbors on a certain device
             continue
         get_bgp_neighbors_minion_out = get_bgp_neighbors_minion.get("out", {})
-        for vrf, vrf_bgp_neighbors in six.iteritems(
-            get_bgp_neighbors_minion_out
-        ):  # pylint: disable=unused-variable
-            for asn, get_bgp_neighbors_minion_asn in six.iteritems(vrf_bgp_neighbors):
+        for (
+            vrf,
+            vrf_bgp_neighbors,
+        ) in get_bgp_neighbors_minion_out.items():  # pylint: disable=unused-variable
+            for asn, get_bgp_neighbors_minion_asn in vrf_bgp_neighbors.items():
                 if asns and asn not in asns:
                     # if filtering by AS number(s),
                     # will ignore if this AS number key not in that list
