@@ -1,19 +1,15 @@
-# -*- coding: utf-8 -*-
 """
 Control Linux Containers via Salt
 
 :depends: lxc execution module
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import copy
 import logging
 import os
 import time
 
-# Import Salt libs
 import salt.client
 import salt.key
 import salt.utils.args
@@ -21,9 +17,6 @@ import salt.utils.cloud
 import salt.utils.files
 import salt.utils.stringutils
 import salt.utils.virt
-
-# Import 3rd-party lib
-from salt.ext import six
 from salt.utils.odict import OrderedDict as _OrderedDict
 
 log = logging.getLogger(__name__)
@@ -46,15 +39,15 @@ def _do(name, fun, path=None):
     if not host:
         return False
 
-    client = salt.client.get_local_client(__opts__["conf_file"])
-    cmd_ret = client.cmd_iter(
-        host, "lxc.{0}".format(fun), [name], kwarg={"path": path}, timeout=60
-    )
-    data = next(cmd_ret)
-    data = data.get(host, {}).get("ret", None)
-    if data:
-        data = {host: data}
-    return data
+    with salt.client.get_local_client(__opts__["conf_file"]) as client:
+        cmd_ret = client.cmd_iter(
+            host, "lxc.{}".format(fun), [name], kwarg={"path": path}, timeout=60
+        )
+        data = next(cmd_ret)
+        data = data.get(host, {}).get("ret", None)
+        if data:
+            data = {host: data}
+        return data
 
 
 def _do_names(names, fun, path=None):
@@ -72,25 +65,25 @@ def _do_names(names, fun, path=None):
     if not hosts:
         return False
 
-    client = salt.client.get_local_client(__opts__["conf_file"])
-    for host, sub_names in six.iteritems(hosts):
-        cmds = []
-        for name in sub_names:
-            cmds.append(
-                client.cmd_iter(
-                    host,
-                    "lxc.{0}".format(fun),
-                    [name],
-                    kwarg={"path": path},
-                    timeout=60,
+    with salt.client.get_local_client(__opts__["conf_file"]) as client:
+        for host, sub_names in hosts.items():
+            cmds = []
+            for name in sub_names:
+                cmds.append(
+                    client.cmd_iter(
+                        host,
+                        "lxc.{}".format(fun),
+                        [name],
+                        kwarg={"path": path},
+                        timeout=60,
+                    )
                 )
-            )
-        for cmd in cmds:
-            data = next(cmd)
-            data = data.get(host, {}).get("ret", None)
-            if data:
-                ret.update({host: data})
-    return ret
+            for cmd in cmds:
+                data = next(cmd)
+                data = data.get(host, {}).get("ret", None)
+                if data:
+                    ret.update({host: data})
+        return ret
 
 
 def find_guest(name, quiet=False, path=None):
@@ -113,7 +106,7 @@ def find_guest(name, quiet=False, path=None):
             "'quiet' argument is being deprecated." " Please migrate to --quiet"
         )
     for data in _list_iter(path=path):
-        host, l = next(six.iteritems(data))
+        host, l = next(iter(data.items()))
         for x in "running", "frozen", "stopped":
             if name in l[x]:
                 if not quiet:
@@ -138,7 +131,7 @@ def find_guests(names, path=None):
     ret = {}
     names = names.split(",")
     for data in _list_iter(path=path):
-        host, stat = next(six.iteritems(data))
+        host, stat = next(iter(data.items()))
         for state in stat:
             for name in stat[state]:
                 if name in names:
@@ -244,172 +237,178 @@ def init(names, host=None, saltcloud_mode=False, quiet=False, **kwargs):
         ret["comment"] = "A host must be provided"
         ret["result"] = False
         return ret
-    if isinstance(names, six.string_types):
+    if isinstance(names, str):
         names = names.split(",")
     if not isinstance(names, list):
         ret["comment"] = "Container names are not formed as a list"
         ret["result"] = False
         return ret
     # check that the host is alive
-    client = salt.client.get_local_client(__opts__["conf_file"])
     alive = False
-    try:
-        if client.cmd(host, "test.ping", timeout=20).get(host, None):
-            alive = True
-    except (TypeError, KeyError):
-        pass
-    if not alive:
-        ret["comment"] = "Host {0} is not reachable".format(host)
-        ret["result"] = False
-        return ret
+    with salt.client.get_local_client(__opts__["conf_file"]) as client:
+        try:
+            if client.cmd(host, "test.ping", timeout=20).get(host, None):
+                alive = True
+        except (TypeError, KeyError):
+            pass
+        if not alive:
+            ret["comment"] = "Host {} is not reachable".format(host)
+            ret["result"] = False
+            return ret
 
-    log.info("Searching for LXC Hosts")
-    data = __salt__["lxc.list"](host, quiet=True, path=path)
-    for host, containers in six.iteritems(data):
-        for name in names:
-            if name in sum(six.itervalues(containers), []):
-                log.info(
-                    "Container '%s' already exists on host '%s', init "
-                    "can be a NO-OP",
-                    name,
-                    host,
-                )
-    if host not in data:
-        ret["comment"] = "Host '{0}' was not found".format(host)
-        ret["result"] = False
-        return ret
+        log.info("Searching for LXC Hosts")
+        data = __salt__["lxc.list"](host, quiet=True, path=path)
+        for host, containers in data.items():
+            for name in names:
+                if name in sum(containers.values(), []):
+                    log.info(
+                        "Container '%s' already exists on host '%s', init "
+                        "can be a NO-OP",
+                        name,
+                        host,
+                    )
+        if host not in data:
+            ret["comment"] = "Host '{}' was not found".format(host)
+            ret["result"] = False
+            return ret
 
-    kw = salt.utils.args.clean_kwargs(**kwargs)
-    pub_key = kw.get("pub_key", None)
-    priv_key = kw.get("priv_key", None)
-    explicit_auth = pub_key and priv_key
-    approve_key = kw.get("approve_key", True)
-    seeds = {}
-    seed_arg = kwargs.get("seed", True)
-    if approve_key and not explicit_auth:
-        skey = salt.key.Key(__opts__)
-        all_minions = skey.all_keys().get("minions", [])
-        for name in names:
-            seed = seed_arg
-            if name in all_minions:
-                try:
-                    if client.cmd(name, "test.ping", timeout=20).get(name, None):
-                        seed = False
-                except (TypeError, KeyError):
-                    pass
-            seeds[name] = seed
-            kv = salt.utils.virt.VirtKey(host, name, __opts__)
-            if kv.authorize():
-                log.info("Container key will be preauthorized")
-            else:
-                ret["comment"] = "Container key preauthorization failed"
-                ret["result"] = False
-                return ret
-
-    log.info("Creating container(s) '%s' on host '%s'", names, host)
-
-    cmds = []
-    for name in names:
-        args = [name]
         kw = salt.utils.args.clean_kwargs(**kwargs)
-        if saltcloud_mode:
-            kw = copy.deepcopy(kw)
-            kw["name"] = name
-            saved_kwargs = kw
-            kw = client.cmd(
-                host,
-                "lxc.cloud_init_interface",
-                args + [kw],
-                tgt_type="list",
-                timeout=600,
-            ).get(host, {})
-            kw.update(saved_kwargs)
-        name = kw.pop("name", name)
-        # be sure not to seed an already seeded host
-        kw["seed"] = seeds.get(name, seed_arg)
-        if not kw["seed"]:
-            kw.pop("seed_cmd", "")
-        cmds.append(
-            (host, name, client.cmd_iter(host, "lxc.init", args, kwarg=kw, timeout=600))
-        )
-    done = ret.setdefault("done", [])
-    errors = ret.setdefault("errors", _OrderedDict())
+        pub_key = kw.get("pub_key", None)
+        priv_key = kw.get("priv_key", None)
+        explicit_auth = pub_key and priv_key
+        approve_key = kw.get("approve_key", True)
+        seeds = {}
+        seed_arg = kwargs.get("seed", True)
+        if approve_key and not explicit_auth:
+            with salt.key.Key(__opts__) as skey:
+                all_minions = skey.all_keys().get("minions", [])
+                for name in names:
+                    seed = seed_arg
+                    if name in all_minions:
+                        try:
+                            if client.cmd(name, "test.ping", timeout=20).get(
+                                name, None
+                            ):
+                                seed = False
+                        except (TypeError, KeyError):
+                            pass
+                    seeds[name] = seed
+                    kv = salt.utils.virt.VirtKey(host, name, __opts__)
+                    if kv.authorize():
+                        log.info("Container key will be preauthorized")
+                    else:
+                        ret["comment"] = "Container key preauthorization failed"
+                        ret["result"] = False
+                        return ret
 
-    for ix, acmd in enumerate(cmds):
-        hst, container_name, cmd = acmd
-        containers = ret.setdefault(hst, [])
-        herrs = errors.setdefault(hst, _OrderedDict())
-        serrs = herrs.setdefault(container_name, [])
-        sub_ret = next(cmd)
-        error = None
-        if isinstance(sub_ret, dict) and host in sub_ret:
-            j_ret = sub_ret[hst]
-            container = j_ret.get("ret", {})
-            if container and isinstance(container, dict):
-                if not container.get("result", False):
-                    error = container
-            else:
-                error = "Invalid return for {0}: {1} {2}".format(
-                    container_name, container, sub_ret
+        log.info("Creating container(s) '%s' on host '%s'", names, host)
+
+        cmds = []
+        for name in names:
+            args = [name]
+            kw = salt.utils.args.clean_kwargs(**kwargs)
+            if saltcloud_mode:
+                kw = copy.deepcopy(kw)
+                kw["name"] = name
+                saved_kwargs = kw
+                kw = client.cmd(
+                    host,
+                    "lxc.cloud_init_interface",
+                    args + [kw],
+                    tgt_type="list",
+                    timeout=600,
+                ).get(host, {})
+                kw.update(saved_kwargs)
+            name = kw.pop("name", name)
+            # be sure not to seed an already seeded host
+            kw["seed"] = seeds.get(name, seed_arg)
+            if not kw["seed"]:
+                kw.pop("seed_cmd", "")
+            cmds.append(
+                (
+                    host,
+                    name,
+                    client.cmd_iter(host, "lxc.init", args, kwarg=kw, timeout=600),
                 )
-        else:
-            error = sub_ret
-            if not error:
-                error = "unknown error (no return)"
-        if error:
+            )
+        done = ret.setdefault("done", [])
+        errors = ret.setdefault("errors", _OrderedDict())
+
+        for ix, acmd in enumerate(cmds):
+            hst, container_name, cmd = acmd
+            containers = ret.setdefault(hst, [])
+            herrs = errors.setdefault(hst, _OrderedDict())
+            serrs = herrs.setdefault(container_name, [])
+            sub_ret = next(cmd)
+            error = None
+            if isinstance(sub_ret, dict) and host in sub_ret:
+                j_ret = sub_ret[hst]
+                container = j_ret.get("ret", {})
+                if container and isinstance(container, dict):
+                    if not container.get("result", False):
+                        error = container
+                else:
+                    error = "Invalid return for {}: {} {}".format(
+                        container_name, container, sub_ret
+                    )
+            else:
+                error = sub_ret
+                if not error:
+                    error = "unknown error (no return)"
+            if error:
+                ret["result"] = False
+                serrs.append(error)
+            else:
+                container["container_name"] = name
+                containers.append(container)
+                done.append(container)
+
+        # marking ping status as True only and only if we have at
+        # least provisioned one container
+        ret["ping_status"] = bool(len(done))
+
+        # for all provisioned containers, last job is to verify
+        # - the key status
+        # - we can reach them
+        for container in done:
+            # explicitly check and update
+            # the minion key/pair stored on the master
+            container_name = container["container_name"]
+            key = os.path.join(__opts__["pki_dir"], "minions", container_name)
+            if explicit_auth:
+                fcontent = ""
+                if os.path.exists(key):
+                    with salt.utils.files.fopen(key) as fic:
+                        fcontent = salt.utils.stringutils.to_unicode(fic.read()).strip()
+                pub_key = salt.utils.stringutils.to_unicode(pub_key)
+                if pub_key.strip() != fcontent:
+                    with salt.utils.files.fopen(key, "w") as fic:
+                        fic.write(salt.utils.stringutils.to_str(pub_key))
+                        fic.flush()
+            mid = j_ret.get("mid", None)
+            if not mid:
+                continue
+
+            def testping(**kw):
+                mid_ = kw["mid"]
+                ping = client.cmd(mid_, "test.ping", timeout=20)
+                time.sleep(1)
+                if ping:
+                    return "OK"
+                raise Exception("Unresponsive {}".format(mid_))
+
+            ping = salt.utils.cloud.wait_for_fun(testping, timeout=21, mid=mid)
+            if ping != "OK":
+                ret["ping_status"] = False
+                ret["result"] = False
+
+        # if no lxc detected as touched (either inited or verified)
+        # we result to False
+        if not done:
             ret["result"] = False
-            serrs.append(error)
-        else:
-            container["container_name"] = name
-            containers.append(container)
-            done.append(container)
-
-    # marking ping status as True only and only if we have at
-    # least provisioned one container
-    ret["ping_status"] = bool(len(done))
-
-    # for all provisioned containers, last job is to verify
-    # - the key status
-    # - we can reach them
-    for container in done:
-        # explicitly check and update
-        # the minion key/pair stored on the master
-        container_name = container["container_name"]
-        key = os.path.join(__opts__["pki_dir"], "minions", container_name)
-        if explicit_auth:
-            fcontent = ""
-            if os.path.exists(key):
-                with salt.utils.files.fopen(key) as fic:
-                    fcontent = salt.utils.stringutils.to_unicode(fic.read()).strip()
-            pub_key = salt.utils.stringutils.to_unicode(pub_key)
-            if pub_key.strip() != fcontent:
-                with salt.utils.files.fopen(key, "w") as fic:
-                    fic.write(salt.utils.stringutils.to_str(pub_key))
-                    fic.flush()
-        mid = j_ret.get("mid", None)
-        if not mid:
-            continue
-
-        def testping(**kw):
-            mid_ = kw["mid"]
-            ping = client.cmd(mid_, "test.ping", timeout=20)
-            time.sleep(1)
-            if ping:
-                return "OK"
-            raise Exception("Unresponsive {0}".format(mid_))
-
-        ping = salt.utils.cloud.wait_for_fun(testping, timeout=21, mid=mid)
-        if ping != "OK":
-            ret["ping_status"] = False
-            ret["result"] = False
-
-    # if no lxc detected as touched (either inited or verified)
-    # we result to False
-    if not done:
-        ret["result"] = False
-    if not quiet:
-        __jid_event__.fire_event({"message": ret}, "progress")
-    return ret
+        if not quiet:
+            __jid_event__.fire_event({"message": ret}, "progress")
+        return ret
 
 
 def cloud_init(names, host=None, quiet=False, **kwargs):
@@ -450,24 +449,24 @@ def _list_iter(host=None, path=None):
         .. versionadded:: 2015.8.0
     """
     tgt = host or "*"
-    client = salt.client.get_local_client(__opts__["conf_file"])
-    for container_info in client.cmd_iter(tgt, "lxc.list", kwarg={"path": path}):
-        if not container_info:
-            continue
-        if not isinstance(container_info, dict):
-            continue
-        chunk = {}
-        id_ = next(six.iterkeys(container_info))
-        if host and host != id_:
-            continue
-        if not isinstance(container_info[id_], dict):
-            continue
-        if "ret" not in container_info[id_]:
-            continue
-        if not isinstance(container_info[id_]["ret"], dict):
-            continue
-        chunk[id_] = container_info[id_]["ret"]
-        yield chunk
+    with salt.client.get_local_client(__opts__["conf_file"]) as client:
+        for container_info in client.cmd_iter(tgt, "lxc.list", kwarg={"path": path}):
+            if not container_info:
+                continue
+            if not isinstance(container_info, dict):
+                continue
+            chunk = {}
+            id_ = next(iter(container_info.keys()))
+            if host and host != id_:
+                continue
+            if not isinstance(container_info[id_], dict):
+                continue
+            if "ret" not in container_info[id_]:
+                continue
+            if not isinstance(container_info[id_]["ret"], dict):
+                continue
+            chunk[id_] = container_info[id_]["ret"]
+            yield chunk
 
 
 def list_(host=None, quiet=False, path=None):
@@ -516,8 +515,8 @@ def purge(name, delete_key=True, quiet=False, path=None):
         return data
 
     if delete_key:
-        skey = salt.key.Key(__opts__)
-        skey.delete_key(name)
+        with salt.key.Key(__opts__) as skey:
+            skey.delete_key(name)
 
     if data is None:
         return
