@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """
 Management of Docker networks
 
@@ -30,24 +29,17 @@ Management of Docker networks
 These states were moved from the :mod:`docker <salt.states.docker>` state
 module (formerly called **dockerng**) in the 2017.7.0 release.
 """
-from __future__ import absolute_import, print_function, unicode_literals
 
 import copy
 import logging
 import random
 import string
 
-# Import Salt libs
 import salt.utils.dockermod.translate.network
 from salt._compat import ipaddress
 from salt.exceptions import CommandExecutionError
 
-# Import 3rd-party libs
-from salt.ext import six
-from salt.ext.six.moves import range  # pylint: disable=import-error,redefined-builtin
-
-# Enable proper logging
-log = logging.getLogger(__name__)  # pylint: disable=invalid-name
+log = logging.getLogger(__name__)
 
 # Define the module's virtual name
 __virtualname__ = "docker_network"
@@ -73,7 +65,7 @@ def _normalize_pools(existing, desired):
     for pool in desired["Config"]:
         subnet = ipaddress.ip_network(pool.get("Subnet"))
         if pools["desired"][subnet.version] is not None:
-            raise ValueError("Only one IPv{0} pool is permitted".format(subnet.version))
+            raise ValueError("Only one IPv{} pool is permitted".format(subnet.version))
         else:
             pools["desired"][subnet.version] = pool
 
@@ -561,14 +553,14 @@ def present(
 
     if missing_containers:
         ret.setdefault("warnings", []).append(
-            "The following containers do not exist: {0}.".format(
+            "The following containers do not exist: {}.".format(
                 ", ".join(missing_containers)
             )
         )
 
     if stopped_containers:
         ret.setdefault("warnings", []).append(
-            "The following containers are not running: {0}.".format(
+            "The following containers are not running: {}.".format(
                 ", ".join(stopped_containers)
             )
         )
@@ -628,7 +620,7 @@ def present(
         # Set the comment now to say that it already exists, if we need to
         # recreate the network with new config we'll update the comment later.
         ret["comment"] = (
-            "Network '{0}' already exists, and is configured "
+            "Network '{}' already exists, and is configured "
             "as specified".format(name)
         )
         log.trace("Details of docker network '%s': %s", name, network)
@@ -660,7 +652,7 @@ def present(
                 **kwargs
             )
         except CommandExecutionError as exc:
-            ret["comment"] = "Failed to create temp network for comparison: {0}".format(
+            ret["comment"] = "Failed to create temp network for comparison: {}".format(
                 exc.__str__()
             )
             return ret
@@ -673,7 +665,7 @@ def present(
             try:
                 temp_net_info = __salt__["docker.inspect_network"](temp_net_name)
             except CommandExecutionError as exc:
-                ret["comment"] = "Failed to inspect temp network: {0}".format(
+                ret["comment"] = "Failed to inspect temp network: {}".format(
                     exc.__str__()
                 )
                 return ret
@@ -775,7 +767,7 @@ def present(
                 __salt__["docker.remove_network"](temp_net_name)
             except CommandExecutionError as exc:
                 ret.setdefault("warnings", []).append(
-                    "Failed to remove temp network '{0}': {1}.".format(
+                    "Failed to remove temp network '{}': {}.".format(
                         temp_net_name, exc.__str__()
                     )
                 )
@@ -802,14 +794,14 @@ def present(
                 **kwargs
             )
         except Exception as exc:  # pylint: disable=broad-except
-            ret["comment"] = "Failed to create network '{0}': {1}".format(
+            ret["comment"] = "Failed to create network '{}': {}".format(
                 name, exc.__str__()
             )
             return ret
         else:
             action = "recreated" if network is not None else "created"
             ret["changes"][action] = True
-            ret["comment"] = "Network '{0}' {1}".format(
+            ret["comment"] = "Network '{}' {}".format(
                 name,
                 "created" if network is None else "was replaced with updated config",
             )
@@ -834,7 +826,7 @@ def present(
 
     errors = []
     if to_connect:
-        for cid, connect_info in six.iteritems(to_connect):
+        for cid, connect_info in to_connect.items():
             connect_kwargs = {}
             if cid in disconnected_containers:
                 for key_name, arg_name in (
@@ -890,7 +882,7 @@ def present(
     # a list of containers was passed in the "containers" argument, and there
     # were containers connected to the network prior to its replacement which
     # were not part of that list.
-    for cid, c_info in six.iteritems(disconnected_containers):
+    for cid, c_info in disconnected_containers.items():
         if cid not in to_connect:
             ret["changes"].setdefault("disconnected", []).append(c_info["Name"])
 
@@ -926,12 +918,12 @@ def absent(name):
 
     if network is None:
         ret["result"] = True
-        ret["comment"] = "Network '{0}' already absent".format(name)
+        ret["comment"] = "Network '{}' already absent".format(name)
         return ret
 
     if __opts__["test"]:
         ret["result"] = None
-        ret["comment"] = "Network '{0}' will be removed".format(name)
+        ret["comment"] = "Network '{}' will be removed".format(name)
         return ret
 
     return _remove_network(network)
@@ -956,7 +948,7 @@ def _remove_network(network):
         try:
             __salt__["docker.disconnect_container_from_network"](cid, network["Name"])
         except CommandExecutionError as exc:
-            errors = "Failed to disconnect container '{0}' : {1}".format(cname, exc)
+            errors = "Failed to disconnect container '{}' : {}".format(cname, exc)
         else:
             ret["changes"].setdefault("disconnected", []).append(cname)
 
@@ -967,10 +959,10 @@ def _remove_network(network):
     try:
         __salt__["docker.remove_network"](network["Name"])
     except CommandExecutionError as exc:
-        ret["comment"] = "Failed to remove network: {0}".format(exc)
+        ret["comment"] = "Failed to remove network: {}".format(exc)
     else:
         ret["changes"]["removed"] = True
         ret["result"] = True
-        ret["comment"] = "Removed network '{0}'".format(network["Name"])
+        ret["comment"] = "Removed network '{}'".format(network["Name"])
 
     return ret
