@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-'''
+"""
 Manage package remote repo using FreeBSD pkgng
 ==============================================
 
@@ -12,21 +12,16 @@ typically rather simple:
     pkgng_clients:
       pkgng.update_packaging_site:
         - name: "http://192.168.0.2"
-'''
+"""
 from __future__ import absolute_import, print_function, unicode_literals
 
 
 def update_packaging_site(name):
-    ret = {
-            'name': name,
-            'changes': {},
-            'result': False,
-            'comment': ''
-            }
+    ret = {"name": name, "changes": {}, "result": False, "comment": ""}
 
-    __salt__['pkgng.update_package_site'](name)
-#    cmd = 'diff /usr/local/etc/pkg.conf /usr/local/etc/pkg.conf.bak'
-#    res = __salt__['cmd.run'](cmd)
-#    ret['changes'] = res
-    ret['result'] = True
+    __salt__["pkgng.update_package_site"](name)
+    #    cmd = 'diff /usr/local/etc/pkg.conf /usr/local/etc/pkg.conf.bak'
+    #    res = __salt__['cmd.run'](cmd)
+    #    ret['changes'] = res
+    ret["result"] = True
     return ret
