@@ -2,10 +2,13 @@
 Generate the salt thin tarball from the installed python files
 """
 
+import contextvars as py_contextvars
 import copy
+import importlib.util
 import logging
 import os
 import shutil
+import site
 import subprocess
 import sys
 import tarfile
@@ -26,6 +29,16 @@ import salt.utils.stringutils
 import salt.version
 import yaml
 
+# This is needed until we drop support for python 3.6
+has_immutables = False
+try:
+    import immutables
+
+    has_immutables = True
+except ImportError:
+    pass
+
+
 try:
     import zlib
 except ImportError:
@@ -82,6 +95,74 @@ else:
 log = logging.getLogger(__name__)
 
 
+def import_module(name, path):
+    """
+    Import a module from a specific path. Path can be a full or relative path
+    to a .py file.
+
+    :name: The name of the module to import
+    :path: The path of the module to import
+    """
+    try:
+        spec = importlib.util.spec_from_file_location(name, path)
+    except ValueError:
+        spec = None
+    if spec is not None:
+        lib = importlib.util.module_from_spec(spec)
+        try:
+            spec.loader.exec_module(lib)
+        except OSError:
+            pass
+        else:
+            return lib
+
+
+def getsitepackages():
+    """
+    Some versions of Virtualenv ship a site.py without getsitepackages. This
+    method will first try and return sitepackages from the default site module
+    if no method exists we will try importing the site module from every other
+    path in sys.paths until we find a getsitepackages method to return the
+    results from. If for some reason no gesitepackages method can be found a
+    RuntimeError will be raised
+
+    :return: A list containing all global site-packages directories.
+    """
+    if hasattr(site, "getsitepackages"):
+        return site.getsitepackages()
+    for path in sys.path:
+        lib = import_module("site", os.path.join(path, "site.py"))
+        if hasattr(lib, "getsitepackages"):
+            return lib.getsitepackages()
+    raise RuntimeError("Unable to locate a getsitepackages method")
+
+
+def find_site_modules(name):
+    """
+    Finds and imports a module from site packages directories.
+
+    :name: The name of the module to import
+    :return: A list of imported modules, if no modules are imported an empty
+             list is returned.
+    """
+    libs = []
+    site_paths = []
+    try:
+        site_paths = getsitepackages()
+    except RuntimeError:
+        log.debug("No site package directories found")
+    for site_path in site_paths:
+        path = os.path.join(site_path, "{}.py".format(name))
+        lib = import_module(name, path)
+        if lib:
+            libs.append(lib)
+        path = os.path.join(site_path, name, "__init__.py")
+        lib = import_module(name, path)
+        if lib:
+            libs.append(lib)
+    return libs
+
+
 def _get_salt_call(*dirs, **namespaces):
     """
     Return salt-call source, based on configuration.
@@ -339,7 +420,7 @@ def get_tops(extra_mods="", so_mods=""):
     :return:
     """
     tops = []
-    for mod in [
+    mods = [
         salt,
         distro,
         jinja2,
@@ -353,7 +434,17 @@ def get_tops(extra_mods="", so_mods=""):
         ssl_match_hostname,
         markupsafe,
         backports_abc,
-    ]:
+    ]
+    modules = find_site_modules("contextvars")
+    if modules:
+        contextvars = modules[0]
+    else:
+        contextvars = py_contextvars
+    log.debug("Using contextvars %r", contextvars)
+    mods.append(contextvars)
+    if has_immutables:
+        mods.append(immutables)
+    for mod in mods:
         if mod:
             log.debug('Adding module to the tops: "%s"', mod.__name__)
             _add_dependency(tops, mod)
