@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
 """
 Resources needed by pkg providers
 """
 
-# Import python libs
-from __future__ import absolute_import, print_function, unicode_literals
 
 import copy
 import fnmatch
@@ -12,15 +9,11 @@ import logging
 import os
 import pprint
 
-# Import salt libs
 import salt.utils.data
 import salt.utils.versions
 import salt.utils.yaml
 from salt.exceptions import SaltInvocationError
 
-# Import third party libs
-from salt.ext import six
-
 log = logging.getLogger(__name__)
 __SUFFIX_NOT_NEEDED = ("x86_64", "noarch")
 
@@ -34,15 +27,10 @@ def _repack_pkgs(pkgs, normalize=True):
         _normalize_name = __salt__["pkg.normalize_name"]
     else:
         _normalize_name = lambda pkgname: pkgname
-    return dict(
-        [
-            (
-                _normalize_name(six.text_type(x)),
-                six.text_type(y) if y is not None else y,
-            )
-            for x, y in six.iteritems(salt.utils.data.repack_dictlist(pkgs))
-        ]
-    )
+    return {
+        _normalize_name(str(x)): str(y) if y is not None else y
+        for x, y in salt.utils.data.repack_dictlist(pkgs).items()
+    }
 
 
 def pack_sources(sources, normalize=True):
@@ -74,7 +62,7 @@ def pack_sources(sources, normalize=True):
     else:
         _normalize_name = lambda pkgname: pkgname
 
-    if isinstance(sources, six.string_types):
+    if isinstance(sources, str):
         try:
             sources = salt.utils.yaml.safe_load(sources)
         except salt.utils.yaml.parser.ParserError as err:
@@ -149,7 +137,7 @@ def parse_targets(
             return None, None
 
         srcinfo = []
-        for pkg_name, pkg_src in six.iteritems(sources):
+        for pkg_name, pkg_src in sources.items():
             if __salt__["config.valid_fileproto"](pkg_src):
                 # Cache package from remote source (salt master, HTTP, FTP) and
                 # append the cached path.
@@ -159,7 +147,7 @@ def parse_targets(
                 # package file.
                 if not os.path.isabs(pkg_src):
                     raise SaltInvocationError(
-                        "Path {0} for package {1} is either not absolute or "
+                        "Path {} for package {} is either not absolute or "
                         "an invalid protocol".format(pkg_src, pkg_name)
                     )
                 srcinfo.append(pkg_src)
@@ -171,9 +159,9 @@ def parse_targets(
             _normalize_name = __salt__.get(
                 "pkg.normalize_name", lambda pkgname: pkgname
             )
-            packed = dict([(_normalize_name(x), version) for x in name.split(",")])
+            packed = {_normalize_name(x): version for x in name.split(",")}
         else:
-            packed = dict([(x, version) for x in name.split(",")])
+            packed = {x: version for x in name.split(",")}
         return packed, "repository"
 
     else:
@@ -211,7 +199,7 @@ def version(*names, **kwargs):
     # return dict
     if len(ret) == 1 and not pkg_glob:
         try:
-            return next(six.itervalues(ret))
+            return next(iter(ret.values()))
         except StopIteration:
             return ""
     return ret
@@ -411,7 +399,7 @@ def format_version(epoch, version, release):
     """
     Formats a version string for list_pkgs.
     """
-    full_version = "{0}:{1}".format(epoch, version) if epoch else version
+    full_version = "{}:{}".format(epoch, version) if epoch else version
     if release:
-        full_version += "-{0}".format(release)
+        full_version += "-{}".format(release)
     return full_version
